import { GetGen, GetGen2 } from "../typegenTypeHelpers";
import { AllNexusInputTypeDefs } from "./wrapping";
export interface CommonArgConfig {
  /**
   * Whether the field is required, `required: true` = `nullable: false`
   */
  required?: boolean;
  /**
   * Whether the field is nullable, `nullable: true` = `required: false`
   */
  nullable?: boolean;
  /**
   * Whether the argument is a list or not.
   *
   * null = not a list
   * true = list
   * array = nested list, where true/false decides
   * whether the list member can be nullable
   */
  list?: null | true | boolean[];
  /**
   * The description to annotate the GraphQL SDL
   */
  description?: string | null;
}
export interface ScalarArgConfig<T> extends CommonArgConfig {
  /**
   * Configure the default for the object
   */
  default?: T;
}
export interface NexusArgConfig<T extends GetGen<"allInputTypes", string>>
  extends CommonArgConfig {
  /**
   * The type of the argument, either the string name of the type,
   * or the concrete Nexus type definition
   */
  type: T | AllNexusInputTypeDefs<T>;
  /**
   * Configure the default for the object
   */
  default?: GetGen2<"allTypes", T>;
}
export declare class NexusArgDef<TypeName extends string> {
  readonly name: TypeName;
  protected config: NexusArgConfig<any>;
  constructor(name: TypeName, config: NexusArgConfig<any>);
  readonly value: NexusArgConfig<any>;
}
/**
 * Defines an argument that can be used in any object or interface type
 *
 * Takes the GraphQL type name and any options.
 *
 * The value returned from this argument can be used multiple times in any valid `args` object value
 *
 * @see https://graphql.github.io/learn/schema/#arguments
 */
export declare function arg<T extends GetGen<"allInputTypes", string>>(
  options: {
    type: T | AllNexusInputTypeDefs<T>;
  } & NexusArgConfig<T>
): NexusArgDef<any>;
export declare function stringArg(
  options?: ScalarArgConfig<string>
): NexusArgDef<any>;
export declare function intArg(
  options?: ScalarArgConfig<number>
): NexusArgDef<any>;
export declare function floatArg(
  options?: ScalarArgConfig<number>
): NexusArgDef<any>;
export declare function idArg(
  options?: ScalarArgConfig<string>
): NexusArgDef<any>;
export declare function booleanArg(
  options?: ScalarArgConfig<boolean>
): NexusArgDef<any>;
