import {
  OutputDefinitionBlock,
  OutputDefinitionBuilder,
} from "./definitionBlocks";
import { GetGen2, GetGen, FieldResolver } from "../typegenTypeHelpers";
import { NonNullConfig } from "./_types";
import { NexusInterfaceTypeDef } from "./interfaceType";
export declare type Implemented =
  | GetGen<"interfaceNames">
  | NexusInterfaceTypeDef<string>;
export interface FieldModification<
  TypeName extends string,
  FieldName extends string
> {
  /**
   * The description to annotate the GraphQL SDL
   */
  description?: string | null;
  /**
   * The resolve method we should be resolving the field with
   */
  resolve?: FieldResolver<TypeName, FieldName>;
}
export interface FieldModificationDef<
  TypeName extends string,
  FieldName extends string
> extends FieldModification<TypeName, FieldName> {
  field: FieldName;
}
export interface ObjectDefinitionBuilder<TypeName extends string>
  extends OutputDefinitionBuilder {
  addInterfaces(toAdd: Implemented[]): void;
  addFieldModifications<FieldName extends string>(
    changes: FieldModificationDef<TypeName, FieldName>
  ): void;
}
export declare class ObjectDefinitionBlock<
  TypeName extends string
> extends OutputDefinitionBlock<TypeName> {
  protected typeBuilder: ObjectDefinitionBuilder<TypeName>;
  constructor(typeBuilder: ObjectDefinitionBuilder<TypeName>);
  /**
   * @param interfaceName
   */
  implements(...interfaceName: Array<Implemented>): void;
  /**
   * Modifies a field added via an interface
   */
  modify<
    FieldName extends Extract<keyof GetGen2<"fieldTypes", TypeName>, string>
  >(
    field: FieldName,
    modifications: FieldModification<TypeName, FieldName>
  ): void;
}
export interface NexusObjectTypeConfig<TypeName extends string> {
  name: TypeName;
  definition(t: ObjectDefinitionBlock<TypeName>): void;
  /**
   * Configures the nullability for the type, check the
   * documentation's "Getting Started" section to learn
   * more about Nexus GraphQL's assumptions and configuration
   * on nullability.
   */
  nonNullDefaults?: NonNullConfig;
  /**
   * The description to annotate the GraphQL SDL
   */
  description?: string | null;
  /**
   * Specifies a default field resolver for all members of this type.
   * Warning: this may break type-safety.
   */
  defaultResolver?: FieldResolver<TypeName, any>;
}
export declare class NexusObjectTypeDef<TypeName extends string> {
  readonly name: TypeName;
  protected config: NexusObjectTypeConfig<string>;
  constructor(name: TypeName, config: NexusObjectTypeConfig<string>);
  readonly value: NexusObjectTypeConfig<string>;
}
export declare function objectType<TypeName extends string>(
  config: NexusObjectTypeConfig<TypeName>
): NexusObjectTypeDef<TypeName>;
export declare function queryType(
  config: NexusObjectTypeConfig<"Query">
): NexusObjectTypeDef<"Query">;
export declare function mutationType(
  config: NexusObjectTypeConfig<"Mutation">
): NexusObjectTypeDef<"Mutation">;
