import {
  GraphQLObjectType,
  GraphQLEnumType,
  GraphQLInterfaceType,
  GraphQLInputObjectType,
  GraphQLScalarType,
  GraphQLUnionType,
  GraphQLSchema,
  GraphQLNamedType,
  GraphQLField,
  GraphQLOutputType,
  GraphQLWrappingType,
} from "graphql";
import { GroupedTypes } from "./utils";
export declare function convertSDL(
  sdl: string,
  commonjs?: null | boolean,
  json?: JSON
): string;
/**
 * Convert an existing SDL schema into a Nexus GraphQL format
 */
export declare class SDLConverter {
  protected json: JSON;
  protected export: string;
  protected schema: GraphQLSchema | null;
  protected groupedTypes: GroupedTypes;
  constructor(sdl: string, commonjs?: null | boolean, json?: JSON);
  print(): string;
  printObjectTypes(): string;
  printObjectType(type: GraphQLObjectType): string;
  printObjectFields(type: GraphQLObjectType | GraphQLInterfaceType): string;
  printField(source: "input" | "output", field: GraphQLField<any, any>): string;
  printFieldMethod(
    source: "input" | "output",
    field: GraphQLField<any, any>,
    type: Exclude<GraphQLOutputType, GraphQLWrappingType>,
    list: boolean[],
    isNonNull: boolean
  ): string;
  printInterfaceTypes(): string;
  printInterfaceType(type: GraphQLInterfaceType): string;
  printEnumTypes(): string;
  printEnumType(type: GraphQLEnumType): string;
  printInputObjectTypes(): string;
  printInputObjectType(type: GraphQLInputObjectType): string;
  printUnionTypes(): string;
  printUnionType(type: GraphQLUnionType): string;
  printScalarTypes(): string;
  printScalarType(type: GraphQLScalarType): string;
  maybeAsNexusType(type: GraphQLScalarType): string | null;
  maybeDescription(type: GraphQLNamedType): string | null;
  printBlock(block: (string | null)[]): string;
}
